@@ -27,12 +27,14 @@ class BatchOperatorAsync(BatchOperator):
     :param job_name: the name for the job that will run on AWS Batch (templated)
     :param job_definition: the job definition name on AWS Batch
     :param job_queue: the queue name on AWS Batch
-    :param overrides: the `containerOverrides` parameter for boto3 (templated)
+    :param overrides: Removed in apache-airflow-providers-amazon release 8.0.0, use container_overrides instead with the
+        same value.
+    :param container_overrides: the `containerOverrides` parameter for boto3 (templated)
     :param array_properties: the `arrayProperties` parameter for boto3
     :param parameters: the `parameters` for boto3 (templated)
     :param job_id: the job ID, usually unknown (None) until the
         submit_job operation gets the jobId defined by AWS Batch
-    :param waiters: an :class:`.BatchWaiters` object (see note below);
+    :param waiters: an :py:class:`.BatchWaiters` object (see note below);
         if None, polling is used with max_retries and status_retries.
     :param max_retries: exponential back-off retries, 4200 = 48 hours;
         polling is only used when waiters is None
@@ -59,27 +61,36 @@ class BatchOperatorAsync(BatchOperator):
         Submit the job and get the job_id using which we defer and poll in trigger
         """
         self.submit_job(context)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BatchOperatorTrigger(
-                job_id=self.job_id,
-                job_name=self.job_name,
-                job_definition=self.job_definition,
-                job_queue=self.job_queue,
-                overrides=self.overrides,
-                array_properties=self.array_properties,
-                parameters=self.parameters,
-                waiters=self.waiters,
-                tags=self.tags,
-                max_retries=self.hook.max_retries,
-                status_retries=self.hook.status_retries,
-                aws_conn_id=self.hook.aws_conn_id,
-                region_name=self.hook.region_name,
-            ),
-            method_name="execute_complete",
-        )
+        if not self.job_id:
+            raise AirflowException("AWS Batch job - job_id was not found")
+        job = self.hook.get_job_description(self.job_id)
+        job_status = job.get("status")
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+        if job_status == self.hook.SUCCESS_STATE:
+            self.log.info(f"{self.job_id} was completed successfully")
+            return
+
+        if job_status == self.hook.FAILURE_STATE:
+            raise AirflowException(f"{self.job_id} failed")
+
+        if job_status in self.hook.INTERMEDIATE_STATES:
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BatchOperatorTrigger(
+                    job_id=self.job_id,
+                    waiters=self.waiters,
+                    max_retries=self.hook.max_retries,
+                    aws_conn_id=self.hook.aws_conn_id,
+                    region_name=self.hook.region_name,
+                ),
+                method_name="execute_complete",
+            )
+
+        raise AirflowException(f"Unexpected status: {job_status}")
+
+    # Ignoring the override type check because the parent class specifies "context: Any" but specifying it as
+    # "context: Context" is accurate as it's more specific.
+    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:  # type: ignore[override]
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
