@@ -43,6 +43,11 @@ class RedshiftDataOperatorAsync(RedshiftDataOperator):
         if response.get("status") == "error":
             self.execute_complete(context, event=response)
         context["ti"].xcom_push(key="return_value", value=query_ids)
+
+        if redshift_data_hook.queries_are_completed(query_ids, context):
+            self.log.info("%s completed successfully.", self.task_id)
+            return
+
         self.defer(
             timeout=self.execution_timeout,
             trigger=RedshiftDataTrigger(
@@ -62,7 +67,7 @@ class RedshiftDataOperatorAsync(RedshiftDataOperator):
         """
         if event:
             if "status" in event and event["status"] == "error":
-                msg = "context: {0}, error message: {1}".format(context, event["message"])
+                msg = "context: {}, error message: {}".format(context, event["message"])
                 raise AirflowException(msg)
             elif "status" in event and event["status"] == "success":
                 self.log.info("%s completed successfully.", self.task_id)
