@@ -2,10 +2,10 @@ import warnings
 from datetime import timedelta
 from typing import Any, Dict
 
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.sensors.batch import BatchSensor
 
 from astronomer.providers.amazon.aws.triggers.batch import BatchSensorTrigger
+from astronomer.providers.utils.sensor_util import poke, raise_error_or_skip_exception
 from astronomer.providers.utils.typing_compat import Context
 
 
@@ -45,16 +45,17 @@ class BatchSensorAsync(BatchSensor):
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure or a success state"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=BatchSensorTrigger(
-                job_id=self.job_id,
-                aws_conn_id=self.aws_conn_id,
-                region_name=self.region_name,
-                poke_interval=self.poke_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=BatchSensorTrigger(
+                    job_id=self.job_id,
+                    aws_conn_id=self.aws_conn_id,
+                    region_name=self.region_name,
+                    poke_interval=self.poke_interval,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
         """
@@ -63,5 +64,5 @@ class BatchSensorAsync(BatchSensor):
         successful.
         """
         if "status" in event and event["status"] == "error":
-            raise AirflowException(event["message"])
+            raise_error_or_skip_exception(self.soft_fail, event["message"])
         self.log.info(event["message"])
