@@ -2,12 +2,12 @@ import warnings
 from datetime import timedelta
 from typing import Any, Dict, Optional
 
-from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.sensors.redshift_cluster import RedshiftClusterSensor
 
 from astronomer.providers.amazon.aws.triggers.redshift_cluster import (
     RedshiftClusterSensorTrigger,
 )
+from astronomer.providers.utils.sensor_util import poke, raise_error_or_skip_exception
 from astronomer.providers.utils.typing_compat import Context
 
 
@@ -38,17 +38,18 @@ class RedshiftClusterSensorAsync(RedshiftClusterSensor):
 
     def execute(self, context: Context) -> None:
         """Check for the target_status and defers using the trigger"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=RedshiftClusterSensorTrigger(
-                task_id=self.task_id,
-                aws_conn_id=self.aws_conn_id,
-                cluster_identifier=self.cluster_identifier,
-                target_status=self.target_status,
-                poke_interval=self.poke_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=RedshiftClusterSensorTrigger(
+                    task_id=self.task_id,
+                    aws_conn_id=self.aws_conn_id,
+                    cluster_identifier=self.cluster_identifier,
+                    target_status=self.target_status,
+                    poke_interval=self.poke_interval,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Optional[Dict[Any, Any]] = None) -> None:
         """
@@ -58,8 +59,8 @@ class RedshiftClusterSensorAsync(RedshiftClusterSensor):
         """
         if event:
             if "status" in event and event["status"] == "error":
-                msg = "{0}: {1}".format(event["status"], event["message"])
-                raise AirflowException(msg)
+                msg = "{}: {}".format(event["status"], event["message"])
+                raise_error_or_skip_exception(self.soft_fail, msg)
             if "status" in event and event["status"] == "success":
                 self.log.info("%s completed successfully.", self.task_id)
                 self.log.info(
