@@ -1,21 +1,22 @@
-import typing
+from __future__ import annotations
+
 import warnings
 from datetime import timedelta
-from typing import Any, Callable, List, Optional, Sequence, Union, cast
+from typing import Any, Callable, Sequence, cast
 
-from airflow.exceptions import AirflowException
-from airflow.providers.amazon.aws.hooks.s3 import S3Hook
-from airflow.providers.amazon.aws.sensors.s3 import S3KeysUnchangedSensor
+from airflow.exceptions import AirflowSkipException
+from airflow.providers.amazon.aws.sensors.s3 import S3KeySensor, S3KeysUnchangedSensor
 from airflow.sensors.base import BaseSensorOperator
 
 from astronomer.providers.amazon.aws.triggers.s3 import (
     S3KeysUnchangedTrigger,
     S3KeyTrigger,
 )
+from astronomer.providers.utils.sensor_util import poke, raise_error_or_skip_exception
 from astronomer.providers.utils.typing_compat import Context
 
 
-class S3KeySensorAsync(BaseSensorOperator):
+class S3KeySensorAsync(S3KeySensor):
     """
     Waits for one or multiple keys (a file-like instance on S3) to be present in a S3 bucket.
     S3 being a key/value it does not support folders. The path is just a key
@@ -29,6 +30,7 @@ class S3KeySensorAsync(BaseSensorOperator):
         refers to this bucket
     :param wildcard_match: whether the bucket_key should be interpreted as a
         Unix wildcard pattern
+    :param use_regex: whether to use regex to check bucket
     :param check_fn: Function that receives the list of the S3 objects,
         and returns a boolean:
         - ``True``: the criteria is met
@@ -59,51 +61,71 @@ class S3KeySensorAsync(BaseSensorOperator):
     def __init__(
         self,
         *,
-        bucket_key: Union[str, List[str]],
-        bucket_name: Optional[str] = None,
+        bucket_key: str | list[str],
+        bucket_name: str | None = None,
         wildcard_match: bool = False,
-        check_fn: Optional[Callable[..., bool]] = None,
+        use_regex: bool = False,
+        check_fn: Callable[..., bool] | None = None,
         aws_conn_id: str = "aws_default",
-        verify: Optional[Union[str, bool]] = None,
+        verify: str | bool | None = None,
         **kwargs: Any,
     ):
-        super().__init__(**kwargs)
-        self.bucket_name = bucket_name
-        self.bucket_key = [bucket_key] if isinstance(bucket_key, str) else bucket_key
-        self.wildcard_match = wildcard_match
+        self.bucket_key: list[str] = [bucket_key] if isinstance(bucket_key, str) else bucket_key
+        self.use_regex = use_regex
+        super().__init__(
+            bucket_name=bucket_name,
+            bucket_key=self.bucket_key,
+            wildcard_match=wildcard_match,
+            check_fn=check_fn,
+            aws_conn_id=aws_conn_id,
+            verify=verify,
+            **kwargs,
+        )
         self.check_fn = check_fn
-        self.aws_conn_id = aws_conn_id
-        self.verify = verify
-        self.hook: Optional[S3Hook] = None
+        self.should_check_fn = True if check_fn else False
 
     def execute(self, context: Context) -> None:
         """Check for a keys in s3 and defers using the trigger"""
+        try:
+            poke = self.poke(context)
+        except Exception as e:
+            if self.soft_fail:
+                raise AirflowSkipException(str(e))
+            else:
+                raise e
+        if not poke:
+            self._defer()
+
+    def _defer(self) -> None:
         self.defer(
             timeout=timedelta(seconds=self.timeout),
             trigger=S3KeyTrigger(
                 bucket_name=cast(str, self.bucket_name),
                 bucket_key=self.bucket_key,
                 wildcard_match=self.wildcard_match,
-                check_fn=self.check_fn,
+                use_regex=self.use_regex,
                 aws_conn_id=self.aws_conn_id,
                 verify=self.verify,
                 poke_interval=self.poke_interval,
+                soft_fail=self.soft_fail,
+                should_check_fn=self.should_check_fn,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Context, event: Any = None) -> Optional[bool]:
+    def execute_complete(self, context: Context, event: Any = None) -> bool | None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
         successful.
         """
+        if event["status"] == "running":
+            if self.check_fn(event["files"]):  # type: ignore[misc]
+                return None
+            else:
+                self._defer()
         if event["status"] == "error":
-            raise AirflowException(event["message"])
-        elif event["status"] == "success" and "s3_objects" in event:
-            files = typing.cast(List[str], event["s3_objects"])
-            if self.check_fn:
-                return self.check_fn(files)
+            raise_error_or_skip_exception(self.soft_fail, event["message"])
         return None
 
 
@@ -116,7 +138,7 @@ class S3KeySizeSensorAsync(S3KeySensorAsync):
     def __init__(
         self,
         *,
-        check_fn: Optional[Callable[..., bool]] = None,
+        check_fn: Callable[..., bool] | None = None,
         **kwargs: Any,
     ):
         warnings.warn(
@@ -172,22 +194,23 @@ class S3KeysUnchangedSensorAsync(S3KeysUnchangedSensor):
 
     def execute(self, context: Context) -> None:
         """Defers Trigger class to check for changes in the number of objects at prefix in AWS S3"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=S3KeysUnchangedTrigger(
-                bucket_name=self.bucket_name,
-                prefix=self.prefix,
-                inactivity_period=self.inactivity_period,
-                min_objects=self.min_objects,
-                previous_objects=self.previous_objects,
-                inactivity_seconds=self.inactivity_seconds,
-                allow_delete=self.allow_delete,
-                aws_conn_id=self.aws_conn_id,
-                verify=self.verify,
-                last_activity_time=self.last_activity_time,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=S3KeysUnchangedTrigger(
+                    bucket_name=self.bucket_name,
+                    prefix=self.prefix,
+                    inactivity_period=self.inactivity_period,
+                    min_objects=self.min_objects,
+                    previous_objects=self.previous_objects,
+                    inactivity_seconds=self.inactivity_seconds,
+                    allow_delete=self.allow_delete,
+                    aws_conn_id=self.aws_conn_id,
+                    verify=self.verify,
+                    last_activity_time=self.last_activity_time,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Any = None) -> None:
         """
@@ -196,7 +219,7 @@ class S3KeysUnchangedSensorAsync(S3KeysUnchangedSensor):
         successful.
         """
         if event["status"] == "error":
-            raise AirflowException(event["message"])
+            raise_error_or_skip_exception(self.soft_fail, event["message"])
         return None
 
 
@@ -210,10 +233,10 @@ class S3PrefixSensorAsync(BaseSensorOperator):
         self,
         *,
         bucket_name: str,
-        prefix: Union[str, List[str]],
+        prefix: str | list[str],
         delimiter: str = "/",
         aws_conn_id: str = "aws_default",
-        verify: Optional[Union[str, bool]] = None,
+        verify: str | bool | None = None,
         **kwargs: Any,
     ):
         warnings.warn(
