@@ -17,11 +17,14 @@ from airflow.providers.amazon.aws.operators.emr import (
     EmrCreateJobFlowOperator,
     EmrTerminateJobFlowOperator,
 )
+from airflow.utils.state import State
+from airflow.utils.trigger_rule import TriggerRule
 from botocore.exceptions import ClientError
 from requests import get
 
 from astronomer.providers.apache.livy.operators.livy import LivyOperatorAsync
 
+LIVY_CLUSTER = os.getenv("LIVY_CLUSTER", "example_livy_operator_cluster")
 BOTO_DUPLICATE_PERMISSION_ERROR = "InvalidPermission.Duplicate"
 LIVY_JAVA_FILE = os.getenv("LIVY_JAVA_FILE", "/spark-examples.jar")
 LIVY_OPERATOR_INGRESS_PORT = int(os.getenv("LIVY_OPERATOR_INGRESS_PORT", 8998))
@@ -44,7 +47,7 @@ COMMAND_TO_CREATE_PI_FILE: List[str] = [
 ]
 
 JOB_FLOW_OVERRIDES = {
-    "Name": "example_livy_operator_cluster",
+    "Name": LIVY_CLUSTER,
     "ReleaseLabel": "emr-5.35.0",
     "Applications": [
         {"Name": "Spark"},
@@ -75,6 +78,7 @@ JOB_FLOW_OVERRIDES = {
     "Steps": [],
     "JobFlowRole": JOB_FLOW_ROLE,
     "ServiceRole": SERVICE_ROLE,
+    "LogUri": "s3://example_emr_sensor_cluster/",
 }
 
 
@@ -243,6 +247,16 @@ def get_cluster_details(task_instance: Any) -> None:
     )
 
 
+def check_dag_status(**kwargs: Any) -> None:
+    """Raises an exception if any of the DAG's tasks failed and as a result marking the DAG failed."""
+    for task_instance in kwargs["dag_run"].get_task_instances():
+        if (
+            task_instance.current_state() != State.SUCCESS
+            and task_instance.task_id != kwargs["task_instance"].task_id
+        ):
+            raise Exception(f"Task {task_instance.task_id} failed. Failing this DAG run")
+
+
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
     "retries": int(os.getenv("DEFAULT_TASK_RETRIES", 2)),
@@ -251,7 +265,7 @@ default_args = {
 
 with DAG(
     dag_id="example_livy_operator",
-    schedule_interval=None,
+    schedule=None,
     start_date=datetime(2021, 1, 1),
     catchup=False,
     default_args=default_args,
@@ -321,6 +335,15 @@ with DAG(
     )
     # [END howto_operator_emr_terminate_job_flow]
 
+    dag_final_status = PythonOperator(
+        task_id="dag_final_status",
+        provide_context=True,
+        python_callable=check_dag_status,
+        trigger_rule=TriggerRule.ALL_DONE,  # Ensures this task runs even if upstream fails
+        dag=dag,
+        retries=0,
+    )
+
     (
         cluster_creator
         >> describe_created_cluster
@@ -330,4 +353,5 @@ with DAG(
         >> livy_java_task
         >> livy_python_task
         >> remove_cluster
+        >> dag_final_status
     )
