@@ -5,6 +5,7 @@ from typing import Any, AsyncIterator, Dict, List, Tuple
 
 from airflow import AirflowException
 from airflow.models import DagRun, TaskInstance
+from airflow.providers.http.hooks.http import HttpHook
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 from airflow.utils.session import provide_session
 from asgiref.sync import sync_to_async
@@ -62,7 +63,8 @@ class TaskStateTrigger(BaseTrigger):
         hit one of the states yet, or not.
         """
         while True:
-            num_tasks = await self.count_tasks()
+            # mypy confuses typing here
+            num_tasks = await self.count_tasks()  # type: ignore[call-arg]
             if num_tasks == len(self.execution_dates):
                 yield TriggerEvent(True)
             await asyncio.sleep(self.poll_interval)
@@ -86,12 +88,10 @@ class TaskStateTrigger(BaseTrigger):
 
 class DagStateTrigger(BaseTrigger):
     """
-    Waits asynchronously for a task in a different DAG to complete for a
+    Waits asynchronously for a different DAG to complete for a
     specific logical date.
 
     :param dag_id: The dag_id that contains the task you want to wait for
-    :param task_id: The task_id that contains the task you want to
-        wait for. If ``None`` (default value) the sensor waits for the DAG
     :param states: allowed states, default is ``['success']``
     :param execution_dates: The logical date at which DAG run.
     :param poll_interval: The time interval in seconds to check the state.
@@ -129,7 +129,8 @@ class DagStateTrigger(BaseTrigger):
         hit one of the states yet, or not.
         """
         while True:
-            num_dags = await self.count_dags()
+            # mypy confuses typing here
+            num_dags = await self.count_dags()  # type: ignore[call-arg]
             if num_dags == len(self.execution_dates):
                 yield TriggerEvent(True)
             await asyncio.sleep(self.poll_interval)
@@ -169,26 +170,33 @@ class ExternalDeploymentTaskTrigger(HttpTrigger):
 
     async def run(self) -> AsyncIterator["TriggerEvent"]:
         """
-        Makes a series of asynchronous http calls via an http hook poll for state of the job
+        Makes a series of http calls via an http hook poll for state of the job
         run until it reaches a failure state or success state. It yields a Trigger if response state is successful.
         """
         from airflow.utils.state import State
 
-        hook = self._get_async_hook()
+        hook = HttpHook(method="GET", http_conn_id=self.http_conn_id)
         while True:
             try:
-                response = await hook.run(
+                response = hook.run(
                     endpoint=self.endpoint,
                     data=self.data,
                     headers=self.headers,
                     extra_options=self.extra_options,
                 )
-                resp_json = await response.json()
+                resp_json = response.json()
                 if resp_json["state"] in State.finished:
                     yield TriggerEvent(resp_json)
-                else:
-                    await asyncio.sleep(self.poke_interval)
+                    return
+                self.log.info(
+                    "The current status is %s. Sleeping for %s seconds",
+                    resp_json.get("state"),
+                    self.poke_interval,
+                )
+                await asyncio.sleep(self.poke_interval)
             except AirflowException as exc:
+                self.log.info("An error occur while calling API %s", str(exc))
                 if str(exc).startswith("404"):
                     await asyncio.sleep(self.poke_interval)
                 yield TriggerEvent({"state": "error", "message": str(exc)})
+                return
