@@ -114,7 +114,7 @@ default_args = {
 
 with models.DAG(
     dag_id="example_gcp_dataproc",
-    schedule_interval=None,
+    schedule=None,
     start_date=datetime(2021, 1, 1),
     catchup=False,
     default_args=default_args,
