@@ -1,5 +1,7 @@
 """This module contains Google BigQueryAsync providers."""
-from typing import Any, Dict
+from __future__ import annotations
+
+from typing import Any
 
 from airflow.exceptions import AirflowException
 from airflow.models.baseoperator import BaseOperator
@@ -12,6 +14,7 @@ from airflow.providers.google.cloud.operators.bigquery import (
     BigQueryValueCheckOperator,
 )
 from google.api_core.exceptions import Conflict
+from google.cloud.bigquery import CopyJob, ExtractJob, LoadJob, QueryJob
 
 from astronomer.providers.google.cloud.triggers.bigquery import (
     BigQueryCheckTrigger,
@@ -57,9 +60,9 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
     :param project_id: Google Cloud Project where the job is running
     :param location: location the job is running
     :param gcp_conn_id: The connection ID used to connect to Google Cloud.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
+    :param delegate_to: (Removed in apache-airflow-providers-google release 10.0.0, use impersonation_chain instead)
+        The account to impersonate using domain-wide delegation of authority, if any. For this to work, the service
+        account making the request must have domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -69,13 +72,23 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :param cancel_on_kill: Flag which indicates whether cancel the hook's job or not, when on_kill is called
+    :param poll_interval: polling period in seconds to check for the status of job. Defaults to 4 seconds.
     """
 
-    def execute(self, context: Context) -> None:  # noqa: D102
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        poll_interval: float = kwargs.pop("poll_interval", 4.0)
+        super().__init__(*args, **kwargs)
+        self.poll_interval = poll_interval
+
+    def execute(self, context: Context) -> Any:  # noqa: D102
+        kwargs: dict[Any, Any] = {}
+        if hasattr(self, "delegate_to"):
+            kwargs["delegate_to"] = self.delegate_to
         hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
+            location=self.location,
+            **kwargs,
         )
 
         self.hook = hook
@@ -93,7 +106,7 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
             self._handle_job_error(job)
         except Conflict:
             # If the job already exists retrieve it
-            job = hook.get_job(
+            job: CopyJob | QueryJob | LoadJob | ExtractJob = hook.get_job(  # type: ignore[no-redef]
                 project_id=self.project_id,
                 location=self.location,
                 job_id=job_id,
@@ -112,19 +125,25 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
 
         self.job_id = job.job_id
         context["ti"].xcom_push(key="job_id", value=self.job_id)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BigQueryInsertJobTrigger(
-                conn_id=self.gcp_conn_id,
-                job_id=self.job_id,
-                project_id=self.project_id,
-                delegate_to=self.delegate_to,
-                impersonation_chain=self.impersonation_chain,
-            ),
-            method_name="execute_complete",
-        )
+        if job.running():
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryInsertJobTrigger(
+                    conn_id=self.gcp_conn_id,
+                    job_id=self.job_id,
+                    project_id=self.project_id,
+                    impersonation_chain=self.impersonation_chain,
+                    poll_interval=self.poll_interval,
+                    **kwargs,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            job.result()
+            self._handle_job_error(job)
+            return self.job_id
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -137,6 +156,7 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
             self.task_id,
             event["message"],
         )
+        return self.job_id
 
 
 class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
@@ -145,6 +165,11 @@ class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
     for the status in async mode by using the job id
     """
 
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        poll_interval: float = kwargs.pop("poll_interval", 4.0)
+        super().__init__(*args, **kwargs)
+        self.poll_interval = poll_interval
+
     def _submit_job(
         self,
         hook: BigQueryHook,
@@ -168,18 +193,23 @@ class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
         )
         job = self._submit_job(hook, job_id="")
         context["ti"].xcom_push(key="job_id", value=job.job_id)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BigQueryCheckTrigger(
-                conn_id=self.gcp_conn_id,
-                job_id=job.job_id,
-                project_id=hook.project_id,
-                impersonation_chain=self.impersonation_chain,
-            ),
-            method_name="execute_complete",
-        )
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+        if job.running():
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryCheckTrigger(
+                    conn_id=self.gcp_conn_id,
+                    job_id=job.job_id,
+                    project_id=hook.project_id,
+                    impersonation_chain=self.impersonation_chain,
+                    poll_interval=self.poll_interval,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            super().execute(context=context)
+
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -231,9 +261,9 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
     :param selected_fields: List of fields to return (comma-separated). If
         unspecified, all fields are returned.
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
+    :param delegate_to: (Removed in apache-airflow-providers-google release 10.0.0, use impersonation_chain instead)
+        The account to impersonate using domain-wide delegation of authority, if any. For this to work, the service
+        account making the request must have domain-wide delegation enabled.
     :param location: The location used for the operation.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -243,13 +273,19 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
+    :param poll_interval: polling period in seconds to check for the status of job. Defaults to 4 seconds
     """
 
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        poll_interval: float = kwargs.pop("poll_interval", 4.0)
+        super().__init__(*args, **kwargs)
+        self.poll_interval = poll_interval
+
     def _submit_job(  # type: ignore[override]
         self,
         hook: BigQueryHook,
         job_id: str,
-        configuration: Dict[str, Any],
+        configuration: dict[str, Any],
     ) -> BigQueryJob:
         """Submit a new job and get the job id for polling the status using Triggerer."""
         return hook.insert_job(
@@ -260,7 +296,7 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
             nowait=True,
         )
 
-    def generate_query(self) -> str:
+    def generate_query(self) -> str:  # type: ignore[override]
         """
         Generate a select query if selected fields are given or with *
         for the given dataset and table id
@@ -276,33 +312,40 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
     def execute(self, context: Context) -> None:  # noqa: D102
         get_query = self.generate_query()
         configuration = {"query": {"query": get_query}}
-
+        kwargs: dict[Any, Any] = {}
+        if hasattr(self, "delegate_to"):
+            kwargs["delegate_to"] = self.delegate_to
         hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             location=self.location,
             impersonation_chain=self.impersonation_chain,
+            **kwargs,
         )
 
         self.hook = hook
         job = self._submit_job(hook, job_id="", configuration=configuration)
         self.job_id = job.job_id
         context["ti"].xcom_push(key="job_id", value=self.job_id)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BigQueryGetDataTrigger(
-                conn_id=self.gcp_conn_id,
-                job_id=self.job_id,
-                dataset_id=self.dataset_id,
-                table_id=self.table_id,
-                project_id=hook.project_id,
-                delegate_to=self.delegate_to,
-                impersonation_chain=self.impersonation_chain,
-            ),
-            method_name="execute_complete",
-        )
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> Any:
+        if job.running():
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryGetDataTrigger(
+                    conn_id=self.gcp_conn_id,
+                    job_id=self.job_id,
+                    dataset_id=self.dataset_id,
+                    table_id=self.table_id,
+                    project_id=hook.project_id,
+                    impersonation_chain=self.impersonation_chain,
+                    poll_interval=self.poll_interval,
+                    **kwargs,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            super().execute(context=context)
+
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -344,8 +387,14 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :param labels: a dictionary containing labels for the table, passed to BigQuery
+    :param poll_interval: polling period in seconds to check for the status of job. Defaults to 4 seconds.
     """
 
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        poll_interval: float = kwargs.pop("poll_interval", 4.0)
+        super().__init__(*args, **kwargs)
+        self.poll_interval = poll_interval
+
     def _submit_job(
         self,
         hook: BigQueryHook,
@@ -373,25 +422,29 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
 
         self.log.info("Executing SQL check: %s", self.sql2)
         job_2 = self._submit_job(hook, sql=self.sql2, job_id="")
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BigQueryIntervalCheckTrigger(
-                conn_id=self.gcp_conn_id,
-                first_job_id=job_1.job_id,
-                second_job_id=job_2.job_id,
-                project_id=hook.project_id,
-                table=self.table,
-                metrics_thresholds=self.metrics_thresholds,
-                date_filter_column=self.date_filter_column,
-                days_back=self.days_back,
-                ratio_formula=self.ratio_formula,
-                ignore_zero=self.ignore_zero,
-                impersonation_chain=self.impersonation_chain,
-            ),
-            method_name="execute_complete",
-        )
+        if job_1.running() or job_2.running():
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryIntervalCheckTrigger(
+                    conn_id=self.gcp_conn_id,
+                    first_job_id=job_1.job_id,
+                    second_job_id=job_2.job_id,
+                    project_id=hook.project_id,
+                    table=self.table,
+                    metrics_thresholds=self.metrics_thresholds,
+                    date_filter_column=self.date_filter_column,
+                    days_back=self.days_back,
+                    ratio_formula=self.ratio_formula,
+                    ignore_zero=self.ignore_zero,
+                    impersonation_chain=self.impersonation_chain,
+                    poll_interval=self.poll_interval,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            super().execute(context=context)
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -408,6 +461,11 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
 
 
 class BigQueryValueCheckOperatorAsync(BigQueryValueCheckOperator):  # noqa: D101
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        poll_interval: float = kwargs.pop("poll_interval", 4.0)
+        super().__init__(*args, **kwargs)
+        self.poll_interval = poll_interval
+
     def _submit_job(
         self,
         hook: BigQueryHook,
@@ -436,21 +494,25 @@ class BigQueryValueCheckOperatorAsync(BigQueryValueCheckOperator):  # noqa: D101
 
         job = self._submit_job(hook, job_id="")
         context["ti"].xcom_push(key="job_id", value=job.job_id)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=BigQueryValueCheckTrigger(
-                conn_id=self.gcp_conn_id,
-                job_id=job.job_id,
-                project_id=hook.project_id,
-                sql=self.sql,
-                pass_value=self.pass_value,
-                tolerance=self.tol,
-                impersonation_chain=self.impersonation_chain,
-            ),
-            method_name="execute_complete",
-        )
+        if job.running():
+            self.defer(
+                timeout=self.execution_timeout,
+                trigger=BigQueryValueCheckTrigger(
+                    conn_id=self.gcp_conn_id,
+                    job_id=job.job_id,
+                    project_id=hook.project_id,
+                    sql=self.sql,
+                    pass_value=self.pass_value,
+                    tolerance=self.tol,
+                    impersonation_chain=self.impersonation_chain,
+                    poll_interval=self.poll_interval,
+                ),
+                method_name="execute_complete",
+            )
+        else:
+            super().execute(context=context)
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> None:
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
