@@ -6,6 +6,7 @@ from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.dataproc import DataprocHook
 from airflow.providers.google.cloud.links.dataproc import (
     DATAPROC_CLUSTER_LINK,
+    DATAPROC_JOB_LOG_LINK,
     DataprocLink,
 )
 from airflow.providers.google.cloud.operators.dataproc import (
@@ -14,7 +15,8 @@ from airflow.providers.google.cloud.operators.dataproc import (
     DataprocSubmitJobOperator,
     DataprocUpdateClusterOperator,
 )
-from google.api_core.exceptions import AlreadyExists
+from google.api_core.exceptions import AlreadyExists, NotFound
+from google.cloud.dataproc_v1 import Cluster, JobStatus
 
 from astronomer.providers.google.cloud.triggers.dataproc import (
     DataprocCreateClusterTrigger,
@@ -72,7 +74,7 @@ class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
         super().__init__(**kwargs)
         self.polling_interval = polling_interval
 
-    def execute(self, context: Context) -> None:  # type: ignore[override]
+    def execute(self, context: Context) -> Any:
         """Call create cluster API and defer to DataprocCreateClusterTrigger to check the status"""
         hook = DataprocHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         DataprocLink.persist(
@@ -95,24 +97,30 @@ class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
                 raise
             self.log.info("Cluster already exists.")
 
-        end_time: float = time.time() + self.timeout
-
-        self.defer(
-            trigger=DataprocCreateClusterTrigger(
-                project_id=self.project_id,
-                region=self.region,
-                cluster_name=self.cluster_name,
-                end_time=end_time,
-                metadata=self.metadata,
-                delete_on_error=self.delete_on_error,
-                cluster_config=self.cluster_config,
-                labels=self.labels,
-                gcp_conn_id=self.gcp_conn_id,
-                impersonation_chain=self.impersonation_chain,
-                polling_interval=self.polling_interval,
-            ),
-            method_name="execute_complete",
+        cluster = hook.get_cluster(
+            project_id=self.project_id, region=self.region, cluster_name=self.cluster_name
         )
+        if cluster.status.state == cluster.status.State.RUNNING:
+            self.log.info("Cluster created.")
+            return Cluster.to_dict(cluster)
+        else:
+            end_time: float = time.time() + self.timeout
+            self.defer(
+                trigger=DataprocCreateClusterTrigger(
+                    project_id=self.project_id,
+                    region=self.region,
+                    cluster_name=self.cluster_name,
+                    end_time=end_time,
+                    metadata=self.metadata,
+                    delete_on_error=self.delete_on_error,
+                    cluster_config=self.cluster_config,
+                    labels=self.labels,
+                    gcp_conn_id=self.gcp_conn_id,
+                    impersonation_chain=self.impersonation_chain,
+                    polling_interval=self.polling_interval,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Optional[Dict[str, Any]] = None) -> Any:
         """
@@ -182,6 +190,14 @@ class DataprocDeleteClusterOperatorAsync(DataprocDeleteClusterOperator):
             metadata=self.metadata,
         )
 
+        try:
+            hook.get_cluster(project_id=self.project_id, region=self.region, cluster_name=self.cluster_name)
+        except NotFound:
+            self.log.info("Cluster deleted.")
+            return
+        except Exception as e:
+            raise AirflowException(str(e))
+
         end_time: float = time.time() + self.timeout
 
         self.defer(
@@ -242,7 +258,7 @@ class DataprocSubmitJobOperatorAsync(DataprocSubmitJobOperator):
     :param cancel_on_kill: Flag which indicates whether cancel the hook's job or not, when on_kill is called
     """
 
-    def execute(self, context: Context) -> None:
+    def execute(self, context: Context) -> Any:
         """
         Airflow runs this method on the worker and defers using the trigger.
         Submit the job and get the job_id using which we defer and poll in trigger
@@ -260,7 +276,18 @@ class DataprocSubmitJobOperatorAsync(DataprocSubmitJobOperator):
         )
         job_id = job_object.reference.job_id
         self.log.info("Job %s submitted successfully.", job_id)
-        self.job_id = job_id
+        # Save data required for extra links no matter what the job status will be
+        DataprocLink.persist(context=context, task_instance=self, url=DATAPROC_JOB_LOG_LINK, resource=job_id)
+
+        job = self.hook.get_job(project_id=self.project_id, region=self.region, job_id=job_id)
+        state = job.status.state
+        if state == JobStatus.State.DONE:
+            return job_id
+        elif state == JobStatus.State.ERROR:
+            raise AirflowException(f"Job failed:\n{job}")
+        elif state == JobStatus.State.CANCELLED:
+            raise AirflowException(f"Job was cancelled:\n{job}")
+
         self.defer(
             timeout=self.execution_timeout,
             trigger=DataProcSubmitTrigger(
@@ -359,24 +386,29 @@ class DataprocUpdateClusterOperatorAsync(DataprocUpdateClusterOperator):
             retry=self.retry,
             metadata=self.metadata,
         )
-
-        end_time: float = time.time() + self.timeout
-
-        self.defer(
-            trigger=DataprocCreateClusterTrigger(
-                project_id=self.project_id,
-                region=self.region,
-                cluster_name=self.cluster_name,
-                end_time=end_time,
-                metadata=self.metadata,
-                gcp_conn_id=self.gcp_conn_id,
-                impersonation_chain=self.impersonation_chain,
-                polling_interval=self.polling_interval,
-            ),
-            method_name="execute_complete",
+        cluster = hook.get_cluster(
+            project_id=self.project_id, region=self.region, cluster_name=self.cluster_name
         )
+        if cluster.status.state == cluster.status.State.RUNNING:
+            self.log.info("Updated %s cluster.", self.cluster_name)
+        else:
+            end_time: float = time.time() + self.timeout
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, Any]] = None) -> Any:
+            self.defer(
+                trigger=DataprocCreateClusterTrigger(
+                    project_id=self.project_id,
+                    region=self.region,
+                    cluster_name=self.cluster_name,
+                    end_time=end_time,
+                    metadata=self.metadata,
+                    gcp_conn_id=self.gcp_conn_id,
+                    impersonation_chain=self.impersonation_chain,
+                    polling_interval=self.polling_interval,
+                ),
+                method_name="execute_complete",
+            )
+
+    def execute_complete(self, context: Context, event: Dict[str, Any]) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
