@@ -1,13 +1,14 @@
 """This module contains Google GKE operators."""
-from typing import Any, Dict, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import Any, Sequence
 
 from airflow.exceptions import AirflowException
+from airflow.providers.cncf.kubernetes.hooks.kubernetes import KubernetesHook
 from airflow.providers.cncf.kubernetes.operators.kubernetes_pod import (
     KubernetesPodOperator,
 )
-from airflow.providers.google.cloud.operators.kubernetes_engine import (
-    GKEStartPodOperator,
-)
+from airflow.providers.cncf.kubernetes.utils.pod_manager import PodPhase
 from kubernetes.client import models as k8s
 
 from astronomer.providers.cncf.kubernetes.operators.kubernetes_pod import (
@@ -16,6 +17,7 @@ from astronomer.providers.cncf.kubernetes.operators.kubernetes_pod import (
 from astronomer.providers.cncf.kubernetes.triggers.wait_container import (
     PodLaunchTimeoutException,
 )
+from astronomer.providers.google.cloud.gke_utils import _get_gke_config_file
 from astronomer.providers.google.cloud.triggers.kubernetes_engine import (
     GKEStartPodTrigger,
 )
@@ -67,12 +69,12 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
         location: str,
         cluster_name: str,
         use_internal_ip: bool = False,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         regional: bool = False,
         poll_interval: float = 5,
-        logging_interval: Optional[int] = None,
+        logging_interval: int | None = None,
         do_xcom_push: bool = True,
         **kwargs: Any,
     ) -> None:
@@ -84,15 +86,16 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
         self.use_internal_ip = use_internal_ip
         self.impersonation_chain = impersonation_chain
         self.regional = regional
-        self.pod_name: str = ""
-        self.pod_namespace: str = ""
         self.poll_interval = poll_interval
         self.logging_interval = logging_interval
         self.do_xcom_push = do_xcom_push
 
+        self.pod_name: str = ""
+        self.pod_namespace: str = ""
+
     def _get_or_create_pod(self, context: Context) -> None:
         """A wrapper to fetch GKE config and get or create a pod"""
-        with GKEStartPodOperator.get_gke_config_file(
+        with _get_gke_config_file(
             gcp_conn_id=self.gcp_conn_id,
             project_id=self.project_id,
             cluster_name=self.cluster_name,
@@ -100,6 +103,7 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
             regional=self.regional,
             location=self.location,
             use_internal_ip=self.use_internal_ip,
+            cluster_context=self.cluster_context,
         ) as config_file:
             self.config_file = config_file
             self.pod_request_obj = self.build_pod_request_obj(context)
@@ -107,10 +111,48 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
             self.pod_name = self.pod.metadata.name
             self.pod_namespace = self.pod.metadata.namespace
 
-    def execute(self, context: Context) -> None:
+    def execute(self, context: Context) -> Any:
         """Look for a pod, if not found then create one and defer"""
         self._get_or_create_pod(context)
         self.log.info("Created pod=%s in namespace=%s", self.pod_name, self.pod_namespace)
+
+        event = None
+        try:
+            with _get_gke_config_file(
+                gcp_conn_id=self.gcp_conn_id,
+                project_id=self.project_id,
+                cluster_name=self.cluster_name,
+                impersonation_chain=self.impersonation_chain,
+                regional=self.regional,
+                location=self.location,
+                use_internal_ip=self.use_internal_ip,
+                cluster_context=self.cluster_context,
+            ) as config_file:
+                hook_params: dict[str, Any] = {
+                    "cluster_context": self.cluster_context,
+                    "config_file": config_file,
+                    "in_cluster": self.in_cluster,
+                }
+                hook = KubernetesHook(conn_id=None, **hook_params)
+                client = hook.core_v1_client
+                pod = client.read_namespaced_pod(self.pod_name, self.pod_namespace)
+                phase = pod.status.phase
+                if phase == PodPhase.SUCCEEDED:
+                    event = {"status": "done", "namespace": self.namespace, "pod_name": self.name}
+
+                elif phase == PodPhase.FAILED:
+                    event = {
+                        "status": "failed",
+                        "namespace": self.namespace,
+                        "pod_name": self.name,
+                        "description": "Failed to start pod operator",
+                    }
+        except Exception as e:
+            event = {"status": "error", "message": str(e)}
+
+        if event:
+            return self.trigger_reentry(context, event)
+
         self.defer(
             trigger=GKEStartPodTrigger(
                 namespace=self.pod_namespace,
@@ -131,12 +173,12 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
             method_name=self.trigger_reentry.__name__,
         )
 
-    def execute_complete(self, context: Context, event: Dict[str, Any]) -> Any:
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> Any:  # type: ignore[override]
         """Callback for trigger once task reach terminal state"""
         self.trigger_reentry(context=context, event=event)
 
     @staticmethod
-    def raise_for_trigger_status(event: Dict[str, Any]) -> None:
+    def raise_for_trigger_status(event: dict[str, Any]) -> None:
         """Raise exception if pod is not in expected state."""
         if event["status"] == "error":
             description = event["description"]
@@ -145,7 +187,7 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
             else:
                 raise AirflowException(description)
 
-    def trigger_reentry(self, context: Context, event: Dict[str, Any]) -> Any:
+    def trigger_reentry(self, context: Context, event: dict[str, Any]) -> Any:
         """
         Point of re-entry from trigger.
 
@@ -158,7 +200,7 @@ class GKEStartPodOperatorAsync(KubernetesPodOperator):
         remote_pod = None
         self.raise_for_trigger_status(event)
         try:
-            with GKEStartPodOperator.get_gke_config_file(
+            with _get_gke_config_file(
                 gcp_conn_id=self.gcp_conn_id,
                 project_id=self.project_id,
                 cluster_name=self.cluster_name,
