@@ -19,7 +19,7 @@ default_args = {
 with DAG(
     dag_id="example_async_http_sensor",
     start_date=datetime(2022, 1, 1),
-    schedule_interval=None,
+    schedule=None,
     catchup=False,
     default_args=default_args,
     tags=["example", "async", "http"],
