@@ -1,4 +1,7 @@
-from typing import Any, List, Optional, Union
+"""This module contains the Azure WASB hook's asynchronous implementation."""
+from __future__ import annotations
+
+from typing import Any, Union
 
 from airflow.providers.microsoft.azure.hooks.wasb import WasbHook
 from azure.core.exceptions import ResourceNotFoundError
@@ -22,12 +25,13 @@ class WasbHookAsync(WasbHook):
         wasb_conn_id: str = "wasb_default",
         public_read: bool = False,
     ) -> None:
+        """Initialize the hook instance."""
         self.conn_id = wasb_conn_id
         self.public_read = public_read
         self.blob_service_client: BlobServiceClient = self.get_conn()
 
     def get_conn(self) -> BlobServiceClient:
-        """Returns the async BlobServiceClient object."""
+        """Return the async BlobServiceClient object."""
         conn = self.get_connection(self.conn_id)
         extra = conn.extra_dejson or {}
 
@@ -77,7 +81,7 @@ class WasbHookAsync(WasbHook):
 
     def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient:
         """
-        Instantiates a blob client.
+        Instantiate a blob client.
 
         :param container_name: the name of the blob container
         :param blob_name: the name of the blob. This needs not be existing
@@ -100,7 +104,7 @@ class WasbHookAsync(WasbHook):
 
     def _get_container_client(self, container_name: str) -> ContainerClient:
         """
-        Instantiates a container client.
+        Instantiate a container client.
 
         :param container_name: the name of the container
         """
@@ -109,11 +113,11 @@ class WasbHookAsync(WasbHook):
     async def get_blobs_list_async(
         self,
         container_name: str,
-        prefix: Optional[str] = None,
-        include: Optional[List[str]] = None,
+        prefix: str | None = None,
+        include: list[str] | None = None,
         delimiter: str = "/",
         **kwargs: Any,
-    ) -> List[BlobProperties]:
+    ) -> list[BlobProperties]:
         """
         List blobs in a given container.
 
@@ -126,10 +130,10 @@ class WasbHookAsync(WasbHook):
         :param delimiter: filters objects based on the delimiter (for e.g '.csv')
         """
         container = self._get_container_client(container_name)
-        blob_list = []
+        blob_list: list[BlobProperties] = []
         blobs = container.walk_blobs(name_starts_with=prefix, include=include, delimiter=delimiter, **kwargs)
         async for blob in blobs:
-            blob_list.append(blob.name)
+            blob_list.append(blob)
         return blob_list
 
     async def check_for_prefix_async(self, container_name: str, prefix: str, **kwargs: Any) -> bool:
