@@ -2,7 +2,6 @@ import warnings
 from datetime import timedelta
 from typing import Any, Dict, List, Optional
 
-from airflow import AirflowException
 from airflow.providers.microsoft.azure.sensors.wasb import (
     WasbBlobSensor,
     WasbPrefixSensor,
@@ -12,6 +11,7 @@ from astronomer.providers.microsoft.azure.triggers.wasb import (
     WasbBlobSensorTrigger,
     WasbPrefixSensorTrigger,
 )
+from astronomer.providers.utils.sensor_util import poke, raise_error_or_skip_exception
 from astronomer.providers.utils.typing_compat import Context
 
 
@@ -53,17 +53,18 @@ class WasbBlobSensorAsync(WasbBlobSensor):
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure state or success state"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=WasbBlobSensorTrigger(
-                container_name=self.container_name,
-                blob_name=self.blob_name,
-                wasb_conn_id=self.wasb_conn_id,
-                public_read=self.public_read,
-                poke_interval=self.poke_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=WasbBlobSensorTrigger(
+                    container_name=self.container_name,
+                    blob_name=self.blob_name,
+                    wasb_conn_id=self.wasb_conn_id,
+                    public_read=self.public_read,
+                    poke_interval=self.poke_interval,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Dict[str, str]) -> None:
         """
@@ -73,10 +74,8 @@ class WasbBlobSensorAsync(WasbBlobSensor):
         """
         if event:
             if event["status"] == "error":
-                raise AirflowException(event["message"])
+                raise_error_or_skip_exception(self.soft_fail, event["message"])
             self.log.info(event["message"])
-        else:
-            raise AirflowException("Did not receive valid event from the triggerer")
 
 
 class WasbPrefixSensorAsync(WasbPrefixSensor):
@@ -125,19 +124,20 @@ class WasbPrefixSensorAsync(WasbPrefixSensor):
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure state or success state"""
-        self.defer(
-            timeout=timedelta(seconds=self.timeout),
-            trigger=WasbPrefixSensorTrigger(
-                container_name=self.container_name,
-                prefix=self.prefix,
-                include=self.include,
-                delimiter=self.delimiter,
-                wasb_conn_id=self.wasb_conn_id,
-                public_read=self.public_read,
-                poke_interval=self.poke_interval,
-            ),
-            method_name="execute_complete",
-        )
+        if not poke(self, context):
+            self.defer(
+                timeout=timedelta(seconds=self.timeout),
+                trigger=WasbPrefixSensorTrigger(
+                    container_name=self.container_name,
+                    prefix=self.prefix,
+                    include=self.include,
+                    delimiter=self.delimiter,
+                    wasb_conn_id=self.wasb_conn_id,
+                    public_read=self.public_read,
+                    poke_interval=self.poke_interval,
+                ),
+                method_name="execute_complete",
+            )
 
     def execute_complete(self, context: Context, event: Dict[str, str]) -> None:
         """
@@ -147,7 +147,5 @@ class WasbPrefixSensorAsync(WasbPrefixSensor):
         """
         if event:
             if event["status"] == "error":
-                raise AirflowException(event["message"])
+                raise_error_or_skip_exception(self.soft_fail, event["message"])
             self.log.info(event["message"])
-        else:
-            raise AirflowException("Did not receive valid event from the triggerer")
